==> MIDITrail-Ver.1.1.3-Windows_src.zip: MIDITrail/MIDITrail/MTScenePianoRollRain.h <==
//******************************************************************************
//
// MIDITrail / MTScenePianoRollRain
//
// sAm[CV[`NX
//
// Copyright (C) 2010-2012 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "DXDirLight.h"
#include "MTScene.h"
#include "MTFirstPersonCam.h"
#include "MTStars.h"
#include "MTPianoKeyboardCtrl.h"
#include "MTNoteRain.h"
#include "MTDashboard.h"
#include "MTNotePitchBend.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// sAm[CV[`NX
//******************************************************************************
class MTScenePianoRollRain : public MTScene
{
public:

	//RXgN^^fXgN^l
	MTScenePianoRollRain(void);
	virtual ~MTScenePianoRollRain(void);

	//̎擾
	const TCHAR* GetName();

	//
	virtual int Create(
			HWND hWnd,
			LPDIRECT3DDEVICE9 pD3DDevice,
			SMSeqData* pSeqData
		);

	//ϊ
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	void Release();

	//EBhENbNCxgM
	int OnWindowClicked(
			unsigned long button,
			unsigned long wParam,
			unsigned long lParam
		);

	//tJnCxgM
	int OnPlayStart();

	//tICxgM
	int OnPlayEnd();

	//V[PTbZ[WM
	int OnRecvSequencerMsg(
			unsigned long wParam,
			unsigned long lParam
		);

	//߂
	int Rewind();

	//_擾^o^
	void GetDefaultViewParam(MTViewParamMap* pParamMap);
	void GetViewParam(MTViewParamMap* pParamMap);
	void SetViewParam(MTViewParamMap* pParamMap);

	//_Zbg
	void ResetViewpoint();

	//GtFNgݒ
	void SetEffect(MTScene::EffectType type, bool isEnable);

	//txݒ
	void SetPlaySpeedRatio(unsigned long ratio);

protected:

	//CgL
	BOOL m_IsEnableLight;

private:

	//Cg
	DXDirLight m_DirLight;

	//l̃J
	MTFirstPersonCam m_FirstPersonCam;

	//`IuWFNg
	MTStars m_Stars;
	MTPianoKeyboardCtrl m_PianoKeyboardCtrl;
	MTNoteRain m_NoteRain;
	MTNotePitchBend m_NotePitchBend;
	MTDashboard m_Dashboard;

	//}EXړ[h
	bool m_IsMouseCamMode;

	//][h
	bool m_IsAutoRollMode;

	//_
	MTViewParamMap m_ViewParamMap;

	//tʒu
	unsigned long m_CurTickTime;

	//XLbv
	bool m_IsSkipping;

	void _Reset();
	void _SetLightColor(DXDirLight* pLight);

};

==> MIDITrail-Ver.1.2.0-Windows_src.zip: MIDITrail/MIDITrail/MTScenePianoRollRain.h <==
//******************************************************************************
//
// MIDITrail / MTScenePianoRollRain
//
// sAm[CV[`NX
//
// Copyright (C) 2010-2012 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "DXDirLight.h"
#include "MTScene.h"
#include "MTFirstPersonCam.h"
#include "MTStars.h"
#include "MTPianoKeyboardCtrl.h"
#include "MTNoteRain.h"
#include "MTDashboard.h"
#include "MTNotePitchBend.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// sAm[CV[`NX
//******************************************************************************
class MTScenePianoRollRain : public MTScene
{
public:

	//RXgN^^fXgN^l
	MTScenePianoRollRain(void);
	virtual ~MTScenePianoRollRain(void);

	//̎擾
	const TCHAR* GetName();

	//
	virtual int Create(
			HWND hWnd,
			LPDIRECT3DDEVICE9 pD3DDevice,
			SMSeqData* pSeqData
		);

	//ϊ
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	void Release();

	//EBhENbNCxgM
	int OnWindowClicked(
			unsigned long button,
			unsigned long wParam,
			unsigned long lParam
		);

	//tJnCxgM
	int OnPlayStart(LPDIRECT3DDEVICE9 pD3DDevice);

	//tICxgM
	int OnPlayEnd(LPDIRECT3DDEVICE9 pD3DDevice);

	//V[PTbZ[WM
	int OnRecvSequencerMsg(
			unsigned long wParam,
			unsigned long lParam
		);

	//߂
	int Rewind();

	//_擾^o^
	void GetDefaultViewParam(MTViewParamMap* pParamMap);
	void GetViewParam(MTViewParamMap* pParamMap);
	void SetViewParam(MTViewParamMap* pParamMap);

	//_Zbg
	void ResetViewpoint();

	//GtFNgݒ
	void SetEffect(MTScene::EffectType type, bool isEnable);

	//txݒ
	void SetPlaySpeedRatio(unsigned long ratio);

protected:

	//CgL
	BOOL m_IsEnableLight;

private:

	//Cg
	DXDirLight m_DirLight;

	//l̃J
	MTFirstPersonCam m_FirstPersonCam;

	//`IuWFNg
	MTStars m_Stars;
	MTPianoKeyboardCtrl m_PianoKeyboardCtrl;
	MTNoteRain m_NoteRain;
	MTNotePitchBend m_NotePitchBend;
	MTDashboard m_Dashboard;

	//}EXړ[h
	bool m_IsMouseCamMode;

	//][h
	bool m_IsAutoRollMode;

	//_
	MTViewParamMap m_ViewParamMap;

	//tʒu
	unsigned long m_CurTickTime;

	//XLbv
	bool m_IsSkipping;

	void _Reset();
	void _SetLightColor(DXDirLight* pLight);

};
